Skip to contents

Retrieve observations from a particular Minka project. This function can be used to get either observations or information from a project by project name or ID.

Usage

get_minka_obs_project(
  grpid = NULL,
  type = c("info", "observations"),
  raw = FALSE
)

Arguments

grpid

Name of the group as an Minka slug or group ID.

type

Character, either "observations" or "info". "observations" returns all observations, and "info" returns project details similar to what you can find on a project's page.

raw

Logical. If TRUE and searching for project info, returns the raw output of parsed JSON for that project. Otherwise just some basic information is returned as a list.

Details

A Minka slug is usually the project name as a single string with words separated by hyphens. For instance, the project "biomarato-2022-girona" has a slug of "world-oceans-week-2022", which you can find by searching projects on Minka and looking at the project's page's URL.

Examples

if (FALSE) { # \dontrun{
 get_minka_obs_project(8, type = "observations")
 get_minka_obs_project("urbamarbio", type="info",raw=FALSE)
} # }