Skip to contents

Get all the observations of a specific Minka user.

Usage

get_minka_obs_user(username, maxresults = 1000)

Arguments

username

username of the Minka user to fetch records

maxresults

the maximum number of results to return

Value

a list with full details on a given record

Examples

if (FALSE) { # \dontrun{
  m_obs <- get_minka_obs(query="Seabream")
  username<- m_obs$user_login[1]
  get_minka_obs_user(as.character(username))
} # }