Get all the observations of a specific Minka user.
Examples
if (FALSE) { # \dontrun{
m_obs <- get_minka_obs(query="Seabream")
username<- m_obs$user_login[1]
get_minka_obs_user(as.character(username))
} # }
Get all the observations of a specific Minka user.
if (FALSE) { # \dontrun{
m_obs <- get_minka_obs(query="Seabream")
username<- m_obs$user_login[1]
get_minka_obs_user(as.character(username))
} # }